##
##  libev.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2020 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_libev 4.33
%define       V_perl  4.17

#   package information
Name:         libev
Summary:      Asynchronous Event Notification Library
URL:          http://software.schmorp.de/pkg/libev.html
Vendor:       Marc Lehmann, Emanuele Giaquinta
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      MIT-style
Version:      %{V_libev}
Release:      20200320

#   package options
%option       with_perl  no

#   list of sources
Source0:      http://dist.schmorp.de/libev/libev-%{V_libev}.tar.gz
Source1:      http://www.cpan.org/authors/id/M/ML/MLEHMANN/EV-%{V_perl}.tar.gz
Patch0:       libev.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
%if "%{with_perl}" == "yes"
BuildPreReq:  perl, perl-openpkg
PreReq:       perl
%endif

%description
    Libev is a full-featured and high-performance event loop that is
    loosely modelled after (and can emulate) the original libevent.
    Features include child/pid watchers and periodic timers based on
    wallclock (absolute) time (in addition to timers using relative
    timeouts), as well as epoll/kqueue/ports support, fast timer
    management, time jump detection and correction, and ease-of-use.

%track
    prog libev = {
        version   = %{version}
        url       = http://dist.schmorp.de/libev/
        regex     = libev-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %setup -q -D -T -a 1
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --includedir=%{l_prefix}/include/ev \
        --mandir=%{l_prefix}/man \
        --disable-shared
    %{l_make} %{l_mflags -O}
%if "%{with_perl}" == "yes"
    %{l_prefix}/bin/perl-openpkg prepare
    %{l_prefix}/bin/perl-openpkg -d EV-%{V_perl} configure build
%endif

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
%if "%{with_perl}" == "yes"
    %{l_prefix}/bin/perl-openpkg -d EV-%{V_perl} install
    %{l_prefix}/bin/perl-openpkg -F perl-openpkg-files fixate cleanup
%else
    >perl-openpkg-files
%endif
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} `cat perl-openpkg-files`

%files -f files

%clean

